@@ -3,15 +3,11 @@ use strict;
 use warnings;
 package String::Stomp;
 
-our $VERSION = '0.0101'; # VERSION
+our $VERSION = '0.0102'; # VERSION
 # ABSTRACT: Removes empty leading and trailing lines
 
-use Sub::Exporter::Progressive -setup => {
-    exports => [qw/stomp/],
-    groups => {
-        default => [qw/stomp/],
-    },
-};
+use Exporter 'import';
+our @EXPORT = qw/stomp/;
 
 sub stomp($) {
     my $string = shift;
@@ -51,7 +47,7 @@ String::Stomp - Removes empty leading and trailing lines
 
 =head1 VERSION
 
-Version 0.0101, released 2015-05-16.
+Version 0.0102, released 2016-01-09.
 
 =head1 SYNOPSIS
 
@@ -66,15 +62,15 @@ Version 0.0101, released 2015-05-16.
 
     # is exactly the same as
     sub out {
-        print q{            A long
+        print q{        A long
             text.};
     }
 
 =head1 DESCRIPTION
 
-String::Stomp provides C<stomp>, a simple function that removes all leading and trailing lines and only consist of white space or line breaks.
+String::Stomp provides C<stomp>, a simple function that removes all leading and trailing lines that only consist of white space or line breaks.
 
-=head2 METHODS
+=head2 FUNCTIONS
 
 =head3 stomp $string
 
@@ -108,21 +104,21 @@ L<Syntax::Feature::Qs> adds C<qs> and C<qqs> that removes all leading whitespace
 
         sub out {
             print q{This is
-a multi line
+    a multi line
 
-string.};
+    string.};
         }
     }
     package Example::HereDoc {
 
         sub out {
 
-            (my $text = <<"        END") =~ s{^ {8}}{}gm;
+            (my $text = <<"            END") =~ s{^ {12}}{}gm;
                 This is
                 a multi line
 
                 string.
-            END
+                END
             
             $text =~ s{\v\z}{};
             print $text;
@@ -143,7 +139,11 @@ L<String::Util>
 
 =item *
 
-L<qi|Syntax::Feature::Qs>
+L<qs|Syntax::Feature::Qs>
+
+=item *
+
+L<qi|Syntax::Feature::Qi>
 
 =back
 
@@ -161,7 +161,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2015 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
